import Vue from 'vue'
import {getInfo, login} from "@/api/common/login"
import {ACCESS_TOKEN, BEARER} from "@/store/mutation-types"

const user = {
  state: {
    token: '',
    name: '',
    username: '',
    welcome: '',
    avatar: '',
    roles: [],
    info: {},
    buttons: [],
  },

  mutations: {
    SET_TOKEN: (state, token) => {
      state.token = token
    },
    SET_NAME: (state, name) => {
      state.name = name
    },
    SET_AVATAR: (state, avatar) => {
      state.avatar = avatar
    },
    SET_ROLES: (state, roles) => {
      state.roles = roles
    },
    SET_INFO: (state, info) => {
      state.info = info
    },
    SET_BUTTONS: (state, buttons) => {
      state.buttons = buttons
    },
  },

  actions: {
    // 登录
    Login({commit}, userInfo) {
      return new Promise((resolve, reject) => {
        login(userInfo).then(response => {
          if (response.code == SYS_CONST.REQUEST.SUCCEED) {
            let token = BEARER + response.data.token;
            console.log("token====================", token)
            if (userInfo.rememberMe == true) {
              Vue.ls.set(ACCESS_TOKEN, token, response.data.expirationTime)
            } else {
              sessionStorage.setItem(ACCESS_TOKEN, token)
            }
            commit('SET_TOKEN', token)
          }
          resolve(response)
        }).catch(error => {
          reject(error)
        })
      })
    },
    // 获取用户信息
    GetInfo({commit}) {
      return new Promise((resolve, reject) => {
        getInfo().then(response => {
          let data = response.data;
          console.log("userinfo", data);

          const buttonAuthList = [];
          let buttons = data.optResList;
          buttons.forEach(button => {
            if (button.operateKey) {
              buttonAuthList.push(button.operateKey)
            }
          });

          commit('SET_NAME', data.sysUser.realName ? data.sysUser.realName : data.sysUser.username);
          commit('SET_AVATAR', data.sysUser.avatar);
          commit('SET_BUTTONS', buttonAuthList);

          resolve(response)
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 登出
    Logout({commit}) {
      return new Promise((resolve) => {
        commit('SET_TOKEN', '');
        commit('SET_ROLES', []);
        commit('SET_BUTTONS', []);
        Vue.ls.remove(ACCESS_TOKEN);
        sessionStorage.removeItem(ACCESS_TOKEN);
        resolve()
      })
    },

  }
}

export default user